@@ -86,13 +86,7 @@ class StcTextCtrl(wx.stc.StyledTextCtrl):
         else:
             self.__save_path = ""
 
-        # set up the timere that will periodically check if the file has been modified on disk.
-        self.__fl_check_timer = StcTextCtrl.ScheduleTimer(self, self.OnCheckFile)
-        self.__fl_check_timer.Start(1000)
-
-        # set up the autosave timer
-        self.__auto_save_timer = StcTextCtrl.ScheduleTimer(self, self.OnAutosave)
-        self.__auto_save_timer.Start(Config.GetOption("Autosave Interval")*60*1000) # convert  minutes to milliseconds
+        self._SetTimers()
 
         self.__macro_register = [] # stores the macro event sequence
 
@@ -126,6 +120,21 @@ class StcTextCtrl(wx.stc.StyledTextCtrl):
         self.UpdateLangMode()   # apply the language mode
         self.ApplyIDEConfig()   # apply the IDE configurations        
 
+
+    def _SetTimers(self):
+        
+
+        # set up the timer that will periodically check if the file has been modified on disk.
+        self.__fl_check_timer = StcTextCtrl.ScheduleTimer(self, self.OnCheckFile)
+        self.__fl_check_timer.Start(1000)
+
+        # set up the autosave timer
+        self.__auto_save_timer = StcTextCtrl.ScheduleTimer(self, self.OnAutosave)
+        self.__auto_save_timer.Start(Config.GetOption("Autosave Interval")*60*1000) # convert  minutes to milliseconds
+
+
+
+
     def UpdateLangMode(self):
         ext = self.GetFileExtension()
         self.lang_mode = StcFundamentalMode(self) # default mode, it will be changed if a specialized one exists
@@ -157,7 +166,7 @@ class StcTextCtrl(wx.stc.StyledTextCtrl):
                     self.Save(0)
                 else:
                     self.file_last_modified = None
-                del fl_not_exists
+                fl_not_exists.Destroy()
         else:
             message = wx.MessageDialog(self, self._("The file seems unsaved, it does not exists\
  on the disk. Do you wish to save it?"), self._("File Not Saved"),
@@ -166,7 +175,7 @@ class StcTextCtrl(wx.stc.StyledTextCtrl):
                 self.Save(0)
             else:
                 self.file_last_modified = None
-            del message
+            message.Destroy()
 
     def OnCompBrace(self,event):
         """
@@ -230,10 +239,10 @@ class StcTextCtrl(wx.stc.StyledTextCtrl):
             #update the ctags files with the new content
             AutoComplet.AutoComp.UpdateCTagsFiles(self.__main_window.id_range)
 
-            del savefileas_dlg
+            savefileas_dlg.Destroy()
             return True
         else:
-            del savefileas_dlg
+            savefileas_dlg.Destroy()
             return False
 
     def Save(self, event):
@@ -286,8 +295,9 @@ class StcTextCtrl(wx.stc.StyledTextCtrl):
 
         """
         if Config.GetOption("Autosave"):
-            self.Save(0)
-            Log.AddLogEntry(self._("Autosaved ")+self.__save_path)
+            if file_path != "New Document" and file_path != "":
+                self.Save(0)
+                Log.AddLogEntry(self._("Autosaved ")+self.__save_path)
 
 
 
