@@ -440,8 +440,8 @@ class gEcrit(wx.Frame):
         Runs the current document in a xterm window, for testing.
         """
         cur_doc = wx.FindWindowById(text_id)
-        if cur_doc.Save(0):
-            os.system("xterm -e sh runner.sh "+cur_doc.GetFilePath())
+        cur_doc.Save(0)
+        os.system("xterm -e sh runner.sh "+cur_doc.GetFilePath())
 
     def OnGotoBox(self, event, text_id):
         """
